<?php
class ControllerExtensionPaymentAdumo extends Controller {
	private $error = array();

	public function index() {
		/**
		 * load the language file
		 */
		$this->load->language('extension/payment/adumo');
		/**
		 * load the configurations for this extension
		 */
		$this->load->model('setting/setting');

		$this->document->setTitle($this->language->get('heading_title'));
		
		/**
		 * check if the information was posted back to us.
		 * if it was posted back then set the config variables and redirect to
		 * the extensions section.
		 */
		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			/**
			 * set the config variables
			 */
			$this->model_setting_setting->editSetting('payment_adumo', $this->request->post);

			/**
			 * message to print on success
			 */
			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true));
		}

		$data['heading_title'] = $this->language->get('heading_title');

		$data['text_edit'] = $this->language->get('text_edit');
		$data['text_enabled'] = $this->language->get('text_enabled');
		$data['text_disabled'] = $this->language->get('text_disabled');
		$data['text_all_zones'] = $this->language->get('text_all_zones');
		$data['text_yes'] = $this->language->get('text_yes');
		$data['text_no'] = $this->language->get('text_no');
		$data['text_live'] = $this->language->get('text_live');
		$data['text_successful'] = $this->language->get('text_successful');
		$data['text_fail'] = $this->language->get('text_fail');

		$data['entry_merchant'] = $this->language->get('entry_merchant');
		$data['entry_secret'] = $this->language->get('entry_secret');
		$data['entry_payment_url'] = $this->language->get('entry_payment_url');
		$data['entry_suffix'] = $this->language->get('entry_suffix');
		$data['entry_total'] = $this->language->get('entry_total');
		$data['entry_order_status'] = $this->language->get('entry_order_status');
		$data['entry_payment_type'] = $this->language->get('entry_payment_type');
		$data['entry_status'] = $this->language->get('entry_status');
		$data['entry_sort_order'] = $this->language->get('entry_sort_order');
		$data['entry_geo_zone'] = $this->language->get('entry_geo_zone');
		$data['entry_payment_types']= array(
			"All Options"=>"4196B0B8-DB88-42E5-A06D-294A5E4DED87",
			"Card - 3D Secure"=>"23ADADC0-DA2D-4DAC-A128-4845A5D71293",
			"Card - non 3D Secure"=>"904A34AF-0CE9-42B1-9C98-B69E6329D154",
			"Mobicred"=>"4293AD67-6502-4636-A2BE-1EF79A4C1B0D",
			"Masterpass"=>"B34C18C0-2181-4515-98CD-D7C8508476E3",
			"SecureEFT"=>"AEF6F78E-7841-46BF-9914-CD63DD4AAE40",
			"Zapper"=>"500DBADA-1034-41B2-85AA-AB42FB0A5E70"
		);

		$data['help_webhook'] = $this->language->get('help_webhook');
		$data['help_secret'] = $this->language->get('help_secret');
		$data['help_total'] = $this->language->get('help_total');
		$data['help_suffix'] = $this->language->get('help_suffix');
		$data['help_payment_url'] = $this->language->get('help_payment_url');

		$data['button_save'] = $this->language->get('button_save');
		$data['button_cancel'] = $this->language->get('button_cancel');


		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->error['merchant'])) {
			$data['error_merchant'] = $this->error['merchant'];
		} else {
			$data['error_merchant'] = '';
		}

		$data['action'] = $this->url->link('extension/payment/adumo', 'user_token=' . $this->session->data['user_token'], true);

		$data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true);

		if (isset($this->request->post['payment_adumo_merchant_id'])) {
			$data['payment_adumo_merchant_id'] = $this->request->post['payment_adumo_merchant_id'];
		} else {
			$data['payment_adumo_merchant_id'] = $this->config->get('payment_adumo_merchant_id');
		}

		if (isset($this->request->post['payment_adumo_application_id'])) {
			$data['payment_adumo_application_id'] = $this->request->post['payment_adumo_application_id'];
		} else {
			$data['payment_adumo_application_id'] = $this->config->get('payment_adumo_application_id');
		}

		if (isset($this->request->post['payment_adumo_merchant_secret'])) {
			$data['payment_adumo_merchant_secret'] = $this->request->post['payment_adumo_merchant_secret'];
		} else {
			$data['payment_adumo_merchant_secret'] = $this->config->get('payment_adumo_merchant_secret');
		}

		if (isset($this->request->post['payment_adumo_merchant_payment_url'])) {
			$data['payment_adumo_merchant_payment_url'] = $this->request->post['payment_adumo_merchant_payment_url'];
		} else {
			$data['payment_adumo_merchant_payment_url'] = $this->config->get('payment_adumo_merchant_payment_url') ? $this->config->get('payment_adumo_merchant_payment_url') : $this->language->get('text_payment_url');
		}

		if (isset($this->request->post['payment_adumo_merchant_suffix'])) {
			$data['payment_adumo_merchant_suffix'] = $this->request->post['payment_adumo_merchant_suffix'];
		} else {
			$data['payment_adumo_merchant_suffix'] = $this->config->get('payment_adumo_merchant_suffix');
		}

		if (isset($this->request->post['payment_adumo_order_status_id'])) {
			$data['payment_adumo_order_status_id'] = $this->request->post['payment_adumo_order_status_id'];
		} else {
			$data['payment_adumo_order_status_id'] = $this->config->get('payment_adumo_order_status_id');
		}

		/**
		 * load the geo zones
		 */
		if (isset($this->request->post['payment_adumo_geo_zone_id'])) {
			$data['payment_adumo_geo_zone_id'] = $this->request->post['payment_adumo_geo_zone_id'];
		} else {
			$data['payment_adumo_geo_zone_id'] = $this->config->get('payment_adumo_geo_zone_id');
		}

		$this->load->model('localisation/geo_zone');

		$data['geo_zones'] = $this->model_localisation_geo_zone->getGeoZones();

		/**
		 * load the order statuses list
		 */
		$this->load->model('localisation/order_status');

		$data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

		if (isset($this->request->post['payment_adumo_status'])) {
			$data['payment_adumo_status'] = $this->request->post['payment_adumo_status'];
		} else {
			$data['payment_adumo_status'] = $this->config->get('payment_adumo_status');
		}

		if (isset($this->request->post['payment_adumo_total'])) {
			$data['payment_adumo_total'] = $this->request->post['payment_adumo_total'];
		} else {
			$data['payment_adumo_total'] = $this->config->get('payment_adumo_total');
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/payment/adumo', $data));
	}

	public function install(){
		$this->load->model('extension/payment/adumo');

		$this->model_extension_payment_adumo->install();
	}
	
	public function uninstall(){
		$this->load->model('extension/payment/adumo');

		$this->model_extension_payment_adumo->uninstall();
	}
	
	protected function validate() {
		if (!$this->user->hasPermission('modify', 'extension/payment/adumo')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		if (!$this->request->post['payment_adumo_merchant_id']) {
			$this->error['merchant'] = $this->language->get('error_merchant');
		}

		return !$this->error;
	}
}